@@ -13,7 +13,7 @@ use English '-no_match_vars';
 use 5.006;
 
 # Declare package version
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # Patterns to match elements of the LRC file; these are somewhat tolerant
 our %RE = (
@@ -54,7 +54,9 @@ our %RE = (
             )             # End seconds group
         \]            # Closing right bracket
         [\t ]*        # Any tabs or spaces
-        (.*\S)        # Lyric line, capture
+        (             # Lyric line group, capture
+            (?:.*\S)?     # Anything ending with non-whitespace
+        )             # End lyric line group
         \s*           # Any whitespace
         \z            # End of string
     }msx,
@@ -270,7 +272,7 @@ Music::Lyrics::LRC - Manipulate LRC karaoke timed lyrics files
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 DESCRIPTION
 
@@ -466,7 +468,7 @@ This program is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License (2.0). You may obtain a copy of the full
 license at:
 
-<http://www.perlfoundation.org/artistic_license_2_0>
+L<http://www.perlfoundation.org/artistic_license_2_0>
 
 Any use, modification, and distribution of the Standard or Modified Versions is
 governed by this Artistic License. By using, modifying or distributing the
